#**********************************************************************
# Licensed Materials - Property of IBM
#
# 5724-W86 5724-X63
#
# (c) Copyright IBM Corp. 2003, 2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#**********************************************************************


package EngineConfig;


@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

use strict;
use Exporter ();
use NETWORK_REGION_RNC qw(load_network_region_config);

use AudLog;

# DDM configuration
use DDM_MANIP_Config;

# P6 Block Name Renaming Lists

use Block_Name_Mapping;
my $block_rename_list = get_block_rename_list();
my $block_manip_list = get_block_manip_list();

my $kira = 1;
#-------------------------------------------------------------------------------

my $network_region_config = &NETWORK_REGION_RNC::load_network_region_config();

#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------
my @rules = (
    {
        RULE_TYPE                        => 'XML_3GPP',
        RULE_DESC                        => '3GPP XML Interface - Ericsson UTRAN P7',
        XML_3GPP_HANDLER_PACKAGE_NAME    => 'XML_3GPP_Handler',
        INPUT_FILE_DESCRIPTION           => ['^.20.+$'],
        INPUT_DIR_DEPTH                  => 5,
        NUMBER_OF_FILES_TO_PROCESS       => 200,
        ORDER_OF_FILES                   => 'OLDEST_FIRST',
        DIRECTORY_HEADER_FIELDS     => {
            NETWORK_ID  => '\/NETWORK_?([^\/]+)\/?',
            REGION_ID => '\/[^\/]+\/REGION_?([^\/]+)\/?',
        },
        FILENAME_HEADER_FIELDS           => {
          FILENAME => '^(.+)$',
              Type       => '^(\w{1}).+$',
              StartDate  => '^\w{1}(\d{8}).+$',
              StartTime => '^\w{1}\d{8}\.(\d{4}).+$',
              SubNetwork => '^\w{1}\d{8}\.\d{4}[+-]?\d{0,4}-\d{4}[+-]?\d{0,4}_SubNetwork=.+SubNetwork=(\w+),.+$',
              GMT_difference => '^\w{1}\d{8}\.\d{4}([+-]?\d{0,4})-.+$',
              MeContext => '^\w{1}\d{8}\.\d{4}[+-]?\d{0,4}-\d{4}[+-]?\d{0,4}_.+MeContext=(.+)_statsfile.+$'
        },
        XML_PIF_HEADER_ELEMENT_NAMES     => ['ffvv-_f.v','sn','st','vn','cbt','nedn','ts'],
        XML_UNIQUE_PIF_BLOCK_HEADER_ELEMENT_NAMES    => ['mts','gp','moid'],
        XML_3GPP_FILENAME_VALIDATION     =>    {
                                                 Type      => '^(A|B|C|D).+$',
                                                 StartDate => '^\w{1}(\d{8}).+$',
                                                 StartTime => '^\w{1}\d{8}\.(\d{4}).+$',
                                              },
        XML_HEADER_INFO_FOR_PIF_FILENAME     => ['sn','moid','sn_SubNetwork','MeContext','mts'],
        #XML_HEADER_INFO_FOR_PIF_FILENAME     => ['sn'], ## valnt00055253, 26 Sept 2008, LX- was raised due to here. Issue not fix.
        XML_UNIQUE_PIF_BLOCK_ELEMENT_NAME    => 'mi',
        XML_MEASUREMENT_TYPE_ELEMENT_SEQ     => 'mt',
        XML_MEASUREMENT_VALUE_ELEMENT_NAME   => 'mv',
        XML_MEASUREMENT_RESULTS_ELEMENT_SEQ  => 'r',
        XML_OUTPUT_BLOCK_ELEMENT_NAME        => 'moid',
        XML_OUTPUT_BLOCK_DESCRIPTION         => '^(\w[\-\w]*)=\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*[\-\w]*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*',
        XML_OBJECT_INSTANCE_ID_ELEMENT_NAME  => 'moid',
        XML_ENABLE_PIF_PER_MOID              => '0',
        XML_SUSPECT_FLAG_ELEMENT_NAME        => 'sf',
        XML_DATA_FOR_PIF_RECORD              => [ qw( mts SubNetwork ) ],
        XML_ALTERNATIVE_COUNTER_NULL_VALUE   => '-9999',
        XML_MAX_COUNTER_NAME_SIZE            => 60,
        XML_LINE_COUNT_TO_TOP_TRIM           => 0, ## valnt00054888 change from 3 to 0
        XML_ENABLE_PIF_COUNTER_IN_FILENAME   => 1,
        XML_DDM_MANIP_RULES  => ddm_manip_config(),

        HEADER_DATA_RECORD_PROCESSING => sub {
        my ($blkname_ref, $h_ref, $d_ref) = @_;

        my $new_block_name = $$blkname_ref;


        if (exists ($block_rename_list->{$new_block_name})) {
            LogMess ("Renaming $new_block_name to $block_rename_list->{$new_block_name}",5);
            $new_block_name = $block_rename_list->{$new_block_name};
        }

        for ($block_manip_list->{$new_block_name}) {
            /^RBS_RNC_RXI$/ && do {
                if ($h_ref->{MeContext} =~ '^RXI') {
                    LogMess ("Pre-pending RXI_ to $new_block_name",5);
                    $new_block_name = "RXI_" . $new_block_name;
                }
                elsif ($h_ref->{MeContext} eq $h_ref->{SubNetwork}) {
                    LogMess ("Pre-pending RNC_ to $new_block_name",5);
                    $new_block_name = "RNC_" . $new_block_name;
                }
                else {
                    LogMess ("Pre-pending NODEB_ to $new_block_name",5);
                    $new_block_name = "NODEB_" . $new_block_name;
                }
                last;
            };
            /^RNC_RXI$/ && do {
                if ($h_ref->{MeContext} =~ '^RXI') {
                    LogMess ("Pre-pending RXI_ to $new_block_name",5);
                    $new_block_name = "RXI_" . $new_block_name;
                }
                else {
                    LogMess ("Pre-pending RNC_ to $new_block_name",5);
                    $new_block_name = "RNC_" . $new_block_name;
                }
                last;
            };
            /^RBS_RNC$/ && do {
                if ($h_ref->{MeContext} eq $h_ref->{SubNetwork}) {
                    LogMess ("Pre-pending RNC_ to $new_block_name",5);
                    $new_block_name = "RNC_" . $new_block_name;
                }
                else {
                    LogMess ("Pre-pending NODEB_ to $new_block_name",5);
                    $new_block_name = "NODEB_" . $new_block_name;
                }
                last;
            };
        }

        $$blkname_ref = $new_block_name;	

		my @arr = sort(grep(/^nedn_SubNetwork_\d+$/, keys %$h_ref));
		my $index = @arr;
		my $hashkey = "nedn_SubNetwork_$index";		
		if (exists ($h_ref->{$hashkey})) {
			$h_ref->{nedn_SubNetwork} = $h_ref->{$hashkey};
			$d_ref->{nedn_SubNetwork} = $h_ref->{$hashkey};
		}
		
        # valnt00082994 - P7.1 FP1. To lookup NETWORK_ID & REGION_ID if it cannot retrieved from directory name structure
        if (exists $h_ref->{nedn_SubNetwork}) {
            if ((! exists $h_ref->{'NETWORK_ID'} || $h_ref->{'NETWORK_ID'} eq '') || (! exists $h_ref->{'REGION_ID'} || $h_ref->{'REGION_ID'} eq '')) {
                if (uc($h_ref->{nedn_SubNetwork}) eq 
                    $network_region_config->{uc($h_ref->{nedn_SubNetwork})}->{"RNC"})	{
                    defined $h_ref->{'NETWORK_ID'} if ! exists $h_ref->{'NETWORK_ID'};
                    $h_ref->{'NETWORK_ID'} = $network_region_config->{uc($h_ref->{nedn_SubNetwork})}->{"NETWORK"};
                    defined $h_ref->{'REGION_ID'} if ! exists $h_ref->{'REGION_ID'};
                    $h_ref->{'REGION_ID'} = $network_region_config->{uc($h_ref->{nedn_SubNetwork})}->{"REGION"};
                }
                else {
                    defined $h_ref->{'NETWORK_ID'} if ! exists $h_ref->{'NETWORK_ID'};
                    $h_ref->{'NETWORK_ID'} = "DEFAULT";
                    defined $h_ref->{'REGION_ID'} if ! exists $h_ref->{'REGION_ID'};
                    $h_ref->{'REGION_ID'} = "DEFAULT";
                }
            }
        }

        return 0;
    },
    }
);

sub engine_config {
    return \@rules;
}

1;
