#**********************************************************************
# Licensed Materials - Property of IBM
#
# 5724-W86 5724-X63
#
# (c) Copyright IBM Corp. 2003, 2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#**********************************************************************

package NETWORK_REGION_RNC;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

use AudLog;
use File::Basename;
use Text::ParseWords;

require Exporter;
require AutoLoader;
use GenUtils;

# generic module for conversion of date/time data
use Generic_Date_Handler;

@ISA = qw(Exporter AutoLoader);
# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.
@EXPORT = qw(load_network_region_config);

$VERSION = '0.01';

############################################################
#
# Sub: load_network_region_config
#
# Desc: This function loads NETWORK_REGION_RNC.csv.
#
# Returns: a configuration hash reference 
#
############################################################
sub load_network_region_config {
	my $network_region_config = "Network_Region_RNC.csv";
	        
	open(DAT, $network_region_config) || die("Could not open file $network_region_config!");
	my @lines=<DAT>;
	close(DAT);
	
	my %network_region_config = ();
	foreach my $line (@lines) {
		$line =~ s/[\r\n]+//g;
		my ($network_id, $region_id, $rnc) = split(/\,/, uc($line), 3);
			             
		defined $network_region_config{$rnc} if ! exists $network_region_config{$rnc};
				
		$network_region_config{$rnc}{"RNC"} = $rnc;
		$network_region_config{$rnc}{"NETWORK"} = $network_id;
		$network_region_config{$rnc}{"REGION"} = $region_id;
	}

	return \%network_region_config;
}

1;  # tells perl that the package is ready to run
